Render a named list as a Quarto tabset
Source:R/quarto_html_tabset_list.R
quarto_html_tabset_list.RdPrint each element of a list with a level-2 heading (##) suitable for Quarto
tabsets. If title is NULL the list names are used. Typical use is printing
ggplot objects or other printable plot objects so each becomes a separate tab.
Examples
if (FALSE) { # \dontrun{
library(ggplot2)
plots <- list(
One = ggplot(mtcars, aes(mpg, wt)) + geom_point(),
Two = ggplot(mtcars, aes(hp, qsec)) + geom_point()
)
quarto_tabset_list(plots)
} # }