Create overall and by-group summary table
Source:R/table_overall_and_group.R
table_overall_and_group.RdThe Overall column reports percentages for the overall cohort. The group columns report row-wise percentages.
Usage
table_overall_and_group(
d,
name_groupvar,
group_header = "**Group**",
missing = c("ifany", "no", "always")
)Arguments
- d
data.frame. Dataset containing variables to summarize.
- name_groupvar
character(1). Name of the grouping variable (column name) in
dused to produce the grouped summary.- group_header
character(1). Label used as the tab spanner for the grouped columns in the merged table.
- missing
character(1) How to display missing data. Options are "ifany", "no", or "always". Default is "ifany".